@@ -68,6 +68,10 @@ async def download_all(args: argparse.Namespace):
     all_files = [str(f) for f in pathlib.Path(args.output_folder).glob("**/*") if f.is_file()]
     combined = '\t'.join(all_files)
 
+    conn.commit()
+    log('Purging empty directories')
+    deleted = purge_dir(args.output_folder)
+
     log('Finished downloading. Enjoy :)')
     if '.part' in combined:
         log('There are still partial downloads in your folders, please re-run the program.')
