@@ -55,7 +55,7 @@ async def throttle(self, url: URL) -> None:
             self.throttle_times[key] = now
             return
 
-        remaining = delay - elapsed + 1
+        remaining = delay - elapsed + 0.25
 
         log_string = '\nDelaying request to %s for %.2f seconds.' % (host, remaining)
         logger.debug(log_string)
@@ -85,7 +85,7 @@ class Downloader:
 
         self.max_workers = max_workers
         self._semaphore = asyncio.Semaphore(max_workers)
-        self.delay = {'media-files.bunkr.is': 2}
+        self.delay = {'media-files.bunkr.is': 0.5}
         self.throttle_times = {}
 
     """Changed from aiohttp exceptions caught to FailureException to allow for partial downloads."""
@@ -239,6 +239,7 @@ class Downloader:
         (self.folder / self.title).mkdir(parents=True, exist_ok=True)
         async with aiohttp.ClientSession(cookie_jar=self.cookie_jar) as session:
             await self.download_all(self.album_obj, session, show_progress=show_progress)
+        self.connection.commit()
 
 
 def get_downloaders(Cascade: CascadeItem, folder: Path, attempts: int, disable_attempt_limit: bool, threads: int, exclude_videos: bool,
